@@ -79,6 +79,7 @@ Out of the box implementation of the Construct without any override will set the
 
 * Configure least privilege access IAM role for Lambda function
 * Enable reusing connections with Keep-Alive for NodeJs Lambda function
+* Enable X-Ray Tracing
 
 ### Amazon SNS Topic
 
@@ -208,9 +209,7 @@ class LambdaToSnsProps:
         :summary:: The properties for the LambdaToSns class.
         """
         if isinstance(lambda_function_props, dict):
-            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(
-                **lambda_function_props
-            )
+            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
         if isinstance(topic_props, dict):
             topic_props = aws_cdk.aws_sns.TopicProps(**topic_props)
         self._values = {}
